### -*- coding: utf-8 -*- #############################################
#######################################################################
"""MixIn class for content viewlet

$Id: content.py 52240 2008-12-29 00:25:58Z cray $
"""
__author__  = "Andrey Orlov"
__license__ = "GPL"
__version__ = "$Revision: 52240 $"

from ng.lib.viewletbase import ViewletBase

class Content(ViewletBase) :
    """ Content """
